==> rivendell-3.4.0.tar.gz: rivendell-3.4.0/rdhpi/rdhpi_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>RDHPIPlayStream</name>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>No such file or directory</source>
        <translation>Este arquivo ou diretório não existe</translation>
    </message>
    <message>
        <source>No output stream available</source>
        <translation>Não há saída de fluxo disponível</translation>
    </message>
    <message>
        <source>Stream is already open</source>
        <translation>Fluxo já está aberto</translation>
    </message>
    <message>
        <source>Unknown Error:</source>
        <translation>Erro Desconhecido:</translation>
    </message>
</context>
<context>
    <name>RDHPIRecordStream</name>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Unable to create/open file</source>
        <translation>Não foi possível criar/abrir arquivo</translation>
    </message>
    <message>
        <source>Input stream unavailable</source>
        <translation>Não há entrada de fluxo disponível</translation>
    </message>
    <message>
        <source>Stream is already open</source>
        <translation>Fluxo já está aberto</translation>
    </message>
    <message>
        <source>Unknown Error:</source>
        <translation>Erro Desconhecido:</translation>
    </message>
</context>
<context>
    <name>RDHPISoundCard</name>
    <message>
        <source>Input Stream</source>
        <translation>Entrada de fluxo</translation>
    </message>
    <message>
        <source>Output Stream</source>
        <translation>Saída de fluxo</translation>
    </message>
    <message>
        <source>Input Port</source>
        <translation>Porta de Entrada</translation>
    </message>
    <message>
        <source>Output Port</source>
        <translation>Porta de Saída</translation>
    </message>
</context>
</TS>

==> rivendell-3.6.6.tar.gz: rivendell-3.6.6/rdhpi/rdhpi_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>RDHPIPlayStream</name>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>No such file or directory</source>
        <translation>Este arquivo ou diretório não existe</translation>
    </message>
    <message>
        <source>No output stream available</source>
        <translation>Não há saída de fluxo disponível</translation>
    </message>
    <message>
        <source>Stream is already open</source>
        <translation>Fluxo já está aberto</translation>
    </message>
    <message>
        <source>Unknown Error:</source>
        <translation type="obsolete">Erro Desconhecido:</translation>
    </message>
    <message>
        <source>Unknown RDHpiPlayStream Error:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDHPIRecordStream</name>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Unable to create/open file</source>
        <translation>Não foi possível criar/abrir arquivo</translation>
    </message>
    <message>
        <source>Input stream unavailable</source>
        <translation>Não há entrada de fluxo disponível</translation>
    </message>
    <message>
        <source>Stream is already open</source>
        <translation>Fluxo já está aberto</translation>
    </message>
    <message>
        <source>Unknown Error:</source>
        <translation type="obsolete">Erro Desconhecido:</translation>
    </message>
    <message>
        <source>Unknown RDHpiRecordStream Error:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDHPISoundCard</name>
    <message>
        <source>Input Stream</source>
        <translation>Entrada de fluxo</translation>
    </message>
    <message>
        <source>Output Stream</source>
        <translation>Saída de fluxo</translation>
    </message>
    <message>
        <source>Input Port</source>
        <translation>Porta de Entrada</translation>
    </message>
    <message>
        <source>Output Port</source>
        <translation>Porta de Saída</translation>
    </message>
</context>
</TS>
